@@ -1,5 +1,9 @@
 is.squid <- is_squid <- function(x) {
 
+  if (all(is.na(x)) || is.null(x)) {
+    return(x);
+  }
+
   if (inherits(x, "squids")) {
     return(TRUE);
   } else {
