@@ -1,7 +1,10 @@
 #' @rdname unsquiding
-#' @export
-squids_to_datetime <- function(x,
-                               tz = "UTC") {
+#' @export squids_to_datetime
+#' @export squids_to_origin
+#' @export squids_to_POSIXt
+#' @aliases squids_to_datetime squids_to_origin squids_to_POSIXt
+squids_to_datetime <- squids_to_origin <- squids_to_POSIXt <- function(x,
+                                                                       tz = "UTC") {
 
   if (!is.squid(x)) {
     stop("As `x`, you have to pass a vector of SQUIDs (Short Quasi-Unique Identifiers), ",
